import sys
import urllib
import unittest
from paste.fixture import TestApp
from paste.recursive import RecursiveMiddleware

from wsgixml.safexhtml import safexhtml

XHTML_IMT = "application/xhtml+xml"
HTML_IMT = "text/html"

class closeablelist:
    def __init__(self, doc):
        self._doc_iter = iter([doc[:20], doc[20:]])

    def __iter__(self):
        return self

    def next(self):
        return self._doc_iter.next()

    def close(self):
        print "ITERATOR CLOSED"


class TestBasics(unittest.TestCase):
    XHTML =  """\
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
    "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" >
  <head>
    <title>Virtual Library</title>
  </head>
  <body>
    <p>Moved to <a href="http://vlib.org/">vlib.org</a>.</p>
  </body>
</html>
"""

    def setUp(self):
        return

    def app(self, environ, start_response):
        #print "using IMT", app.current_imt
        start_response('200 OK', [('Content-Type', self.current_imt)])
        #Swap the IMT used for response (alternate between XHTML_IMT and HTML_IMT)
        return closeablelist(self.XHTML)

    def test_1(self):
        app = TestApp(safexhtml(RecursiveMiddleware(self.app)))

        self.current_imt = HTML_IMT
        result = app.get('/')
        result.mustcontain('XHTML 1')

        self.current_imt = XHTML_IMT
        result = app.get('/')
        self.assert_('<?xml' not in result)

        self.current_imt = HTML_IMT
        result = app.get('/', headers={'Accept': XHTML_IMT})
        result.mustcontain('XHTML 1')

        self.current_imt = XHTML_IMT
        result = app.get('/', headers={'Accept': XHTML_IMT})
        result.mustcontain('XHTML 1')

        self.current_imt = HTML_IMT
        result = app.get('/', headers={'Accept': HTML_IMT})
        result.mustcontain('XHTML 1')

        self.current_imt = XHTML_IMT
        result = app.get('/', headers={'Accept': HTML_IMT})
        self.assert_('<?xml' not in result)

        return


if __name__ == '__main__':
    unittest.main()




import sys
import urllib
import unittest
from paste.fixture import TestApp
from paste.recursive import RecursiveMiddleware

from wsgixml.applyxslt import applyxslt

class TestBasics(unittest.TestCase):
    XML =  """\
<?xml version="1.0"?>
<?xml-stylesheet href="test.xslt" type="application/xml"?>
<doc/>
"""

    XSLT =  """\
<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">
<xsl:template match="/">
  <result/>
</xsl:template>
</xsl:stylesheet>
"""

    def setUp(self):
        #
        return

    def app(self, environ, start_response):
        start_response('200 OK', [('Content-Type', 'application/xml')])
        if environ['PATH_INFO'].endswith('test.xml'):
            return [self.XML]
        elif environ['PATH_INFO'].endswith('test.xslt'):
            return [self.XSLT]
        return

    def test_1(self):
        app = TestApp(applyxslt(RecursiveMiddleware(self.app)))
        result = app.get('/test.xml')
        result.mustcontain('<result/>')
        result = app.get('/test.xml', headers={'User-Agent': 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.2) Gecko/20060308 Firefox/1.5.0.2'})
        result.mustcontain('<doc/>')
        result = app.get('/test.xml', headers={'User-agent': 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.0.2) Gecko/20060308 Firefox/1.5.0.2'})
        result.mustcontain('<doc/>')
        result = app.get('/test.xml', headers={'User-Agent': 'Buster ass browser'})
        result.mustcontain('<result/>')
        return


if __name__ == '__main__':
    unittest.main()




#!/usr/bin/env python

try:
    from setuptools import setup, find_packages
    setuptools_extras = dict(
        packages=find_packages(),
        install_requires='4Suite-XML>=1.0rc4')

except ImportError:
    from distutils.core import setup
    setuptools_extras = {}

setup(name = "wsgixml",
      version = "0.1",
      description='WSGI middleware modules for XML processing',
      author='Uche Ogbuji',
      author_email='uche@ogbuji.net',
      url='http://uche.ogbuji.net/tech/4suite/wsgixml',
      **setuptools_extras)


